@@ -1,6 +1,8 @@
 import numpy as np
 import math
 import numbers
+# from copy import deepcopy
+# from . import combinations as cc_combinations
 from . import maths as cc_maths
 # from .maths import convert_to_int_or_float, rint
 
@@ -20,6 +22,10 @@ def advanced_indexing(indexes_loose):
     return indexes
 
 
+def samples_in_arr1_are_not_in_arr2(arr1, arr2, axis=0):
+    return np.logical_not(samples_in_arr1_are_in_arr2(arr1, arr2, axis=axis))
+
+
 def samples_in_arr1_are_in_arr2(arr1, arr2, axis=0):
 
     # OLD elements_in_x_are_in_y()
@@ -103,6 +109,8 @@ def samples_in_arr1_are_in_arr2(arr1, arr2, axis=0):
         indexes_arr_logical[axis] = i_sample
         arr_logical[tuple(indexes_arr_logical)] = arr1[tuple(indexes_arr1)] == arr2
 
+        # maybe todo: arr_logical[tuple(indexes_arr_logical)] = np.all(arr1[tuple(indexes_arr1)] == arr2)
+
     elements_of_arr1_in_arr2_logical = np.any(arr_logical, axis=axis + 1)
 
     return elements_of_arr1_in_arr2_logical
@@ -775,3 +783,30 @@ class FloatRange:
             step=len_each_equal_ranges)
         return centers
 
+
+def select_dtype_from_2_arrays(x, y):
+
+    if isinstance(x, np.ndarray):
+        dtype_x = x.dtype
+    else:
+        dtype_x = np.asarray(x).dtype
+
+    if isinstance(y, np.ndarray):
+        dtype_y = y.dtype
+    else:
+        dtype_y = np.asarray(y).dtype
+
+    if dtype_x.kind == dtype_y.kind:
+        if int(dtype_x.str[2:]) > int(dtype_y.str[2:]):
+            dtype_out = dtype_x.str
+        else:
+            dtype_out = dtype_y.str
+
+    elif (dtype_x.kind == 'f') and (dtype_y.kind == 'i'):
+        dtype_out = dtype_x.str
+    elif (dtype_x.kind == 'i') and (dtype_y.kind == 'f'):
+        dtype_out = dtype_y.str
+    else:
+        dtype_out = 'O'
+
+    return dtype_out
