@@ -402,9 +402,13 @@ def make_combinations_of_conditions_as_distributions(conditions_as_distributions
 
 
 def trials_to_combinations(
-        trials, axis_combinations=0, variables=None,  n_repetitions_combinations=1, dtype=None):
+        trials, axis_combinations=0, variables=None, n_repetitions_combinations=1, dtype=None,
+        exclude_values=False, values=-1):
+
+    conditions = trials_to_conditions(
+        trials, axis_combinations=axis_combinations, variables=variables,
+        exclude_values=exclude_values, values=values)
 
-    conditions = trials_to_conditions(trials, axis_combinations=axis_combinations, variables=variables)
     combinations = conditions_to_combinations(
         conditions,
         axis_combinations=axis_combinations,
@@ -413,7 +417,7 @@ def trials_to_combinations(
     return combinations
 
 
-def trials_to_conditions(trials, axis_combinations=0, variables=None):
+def trials_to_conditions(trials, axis_combinations=0, variables=None, exclude_values=False, values=-1):
 
     axis_variables = int(not(bool(axis_combinations)))
     if variables is None:
@@ -438,11 +442,17 @@ def trials_to_conditions(trials, axis_combinations=0, variables=None):
 
         conditions[i_variable] = np.unique(trials_variables_i)
 
+    if exclude_values:
+        conditions = exclude(conditions, values)
+
     return conditions
 
 
-def trials_to_n_conditions(trials, axis_combinations=0, variables=None):
-    conditions = trials_to_conditions(trials, axis_combinations=axis_combinations, variables=variables)
+def trials_to_n_conditions(trials, axis_combinations=0, variables=None, exclude_values=False, values=-1):
+    conditions = trials_to_conditions(
+        trials, axis_combinations=axis_combinations, variables=variables,
+        exclude_values=exclude_values, values=values)
+
     n_conditions = conditions_to_n_conditions(conditions)
     # n_variables = len(conditions)
     # n_conditions = np.empty(n_variables, dtype=int)
@@ -451,11 +461,15 @@ def trials_to_n_conditions(trials, axis_combinations=0, variables=None):
     return n_conditions
 
 
-def n_conditions_to_conditions(n_conditions):
+def n_conditions_to_conditions(n_conditions, exclude_values=False, values=-1):
     n_variables = len(n_conditions)
     conditions = np.empty(n_variables, dtype=object)
     for i_variable in range(n_variables):
         conditions[i_variable] = np.arange(n_conditions[i_variable])
+
+    if exclude_values:
+        conditions = exclude(conditions, values)
+
     return conditions
 
 
@@ -467,6 +481,19 @@ def conditions_to_n_conditions(conditions):
     return n_conditions
 
 
+def exclude(conditions, values=-1, variables=None):
+    n_variables = len(conditions)
+
+    if variables is None:
+        variables = list(range(n_variables))
+
+    for i_variable in range(n_variables):
+        if i_variable in variables:
+            conditions[i_variable] = conditions[i_variable][
+                cc_array.samples_in_arr1_are_not_in_arr2(conditions[i_variable], values)]
+    return conditions
+
+
 def conditions_to_phases_of_blocks_of_shuffled_combinations(
         conditions, n_repetitions_combinations=1, n_repetitions_variables_repeated_per_block=1,
         variables_split=None, n_repetitions_variables_repeated_per_shuffle=None):
@@ -1119,7 +1146,7 @@ def conditions_to_blocks_of_shuffled_combinations(
     return trials_blocks
 
 
-def conditions_to_permutetions(conditions, R, dtype=None):
+def conditions_to_permutations(conditions, R, dtype=None):
     permutations = np.asarray(list(itertools.permutations(conditions, R)), dtype=dtype)
     return permutations
 
@@ -1133,7 +1160,7 @@ def conditions_to_P_random_permutetions(conditions, R=None, P=None, dtype=None):
         n = cc_maths.convert_to_int_or_float(math.factorial(C) / math.factorial(C - R))
 
     if P is None or P >= n:
-        permutations = conditions_to_permutetions(conditions, R)
+        permutations = conditions_to_permutations(conditions, R)
         permutations = cc_array.shuffle_in_any_dimension(permutations, 0)
         return permutations
 
@@ -1141,7 +1168,7 @@ def conditions_to_P_random_permutetions(conditions, R=None, P=None, dtype=None):
         indexes_cond = np.arange(C)
         positions = np.arange(R)
 
-        permutations_indexes = conditions_to_permutetions(indexes_cond, R, dtype='i')
+        permutations_indexes = conditions_to_permutations(indexes_cond, R, dtype='i')
         permutations_indexes = cc_array.shuffle_in_any_dimension(permutations_indexes, 0)
 
         max_per_pos = math.ceil(20 / C)
