@@ -22,7 +22,9 @@ from .strings import format_float_to_str as cc_strings_format_float_to_str
 
 
 class Time:
-    # TODO make range for each directory level
+    # TODO make range for each directory level (this is possible if I make condition_to_combination compatible for
+    #  ranges like this class Time)
+
     def __init__(self, range_time, level, range_shifts=None, n_shifts=None):
 
         if not isinstance(range_time, cc_array.IntRange):
@@ -63,6 +65,7 @@ class Time:
                     self.tmp_shifts = self.possible_shifts * math.ceil(self.n_shifts / self.n_possible_shifts)
                 else:
                     self.shifts = self.possible_shifts * math.ceil(self.n_shifts / self.n_possible_shifts)
+                self.shifts = self.possible_shifts * math.ceil(self.n_shifts / self.n_possible_shifts)
 
     def set_n_shifts(self, n_shifts):
 
@@ -110,20 +113,16 @@ class Loader:
 
     # TODO add inter-sample levels and intra-sample levels
     def __init__(
-            self, directory_root, level_classes, n_levels_directories=None,
-            conditions_directories=None, batch_size=None, n_batches=None,
-            shuffle=False, time=None, transforms=None, device=None,
-            order_outputs='il'):
+            self, directory_root, level_labels, levels_intra_samples=None, conditions_directories=None,
+            batch_size=None, n_batches=None, shuffle=False, time=None,
+            transforms=None, device=None, order_outputs='il'):
         """
         Parameters
         ----------
         directory_root : str
             The directory of the dataset
-        level_classes : int
+        level_labels : int
             The directory level of the classes in the directory tree of the dataset.
-        n_levels_directories : int, optional
-            number of levels of the directory tree of the dataset (default is None). It is required if
-            conditions_directories is None.
         conditions_directories : None or sequence of Nones and sequences of ints, optional
             Conditions_directories can be a sequence or None (default is None). If it is a sequence, the l_th element
             of it is None or a sequence of ints. If the l_th element is a sequence of ints, it contains the conditions
@@ -138,17 +137,49 @@ class Loader:
         """
 
         self.directory_root = directory_root
-        self.level_classes = level_classes
+        self.levels_labels = level_labels
+
+        try:
+            levels_intra_samples[0]
+            if isinstance(levels_intra_samples, np.ndarray):
+                self.levels_intra_sample = levels_intra_samples
+            else:
+                self.levels_intra_sample = np.asarray(levels_intra_samples, dtype='i')
+        except TypeError:
+            self.levels_intra_sample = np.asarray([levels_intra_samples], dtype='i')
 
         self.time = time
 
-        if n_levels_directories is None:
-            self.n_levels_directories = len(conditions_directories)
-        elif conditions_directories is None:
-            self.n_levels_directories = n_levels_directories
-            conditions_directories = [None] * self.n_levels_directories  # type: list
+        l = 0
+        self.conditions_directories_names = []
+        directory_root_l = self.directory_root
+        while os.path.isdir(directory_root_l):
+            self.conditions_directories_names.append(os.listdir(directory_root_l))
+            directory_root_l = os.path.join(directory_root_l, self.conditions_directories_names[l][0])
+            l += 1
+        self.L = self.n_levels_directories = l
+        del l, directory_root_l
 
-        self.L = self.n_levels_directories
+        self.levels_intra_sample[self.levels_intra_sample < 0] += self.L
+
+        self.levels_all = np.arange(self.L, dtype='i')
+        if any(cc_array.samples_in_arr1_are_not_in_arr2(self.levels_intra_sample, self.levels_all)):
+            raise ValueError('levels_intra_samples')
+
+        self.levels_intra_sample = (
+            self.levels_all[cc_array.samples_in_arr1_are_not_in_arr2(self.levels_all, self.levels_intra_sample)])
+
+        if conditions_directories is None:
+            self.conditions_directories = [None] * self.L  # type: list
+        else:
+            try:
+                conditions_directories[0]
+            except TypeError:
+                raise TypeError('conditions_directories')
+            if len(conditions_directories) == self.L:
+                self.conditions_directories = conditions_directories
+            else:
+                raise ValueError('conditions_directories')
 
         self.shuffle = shuffle
 
@@ -159,10 +190,6 @@ class Loader:
 
         self.device = device
 
-        self.conditions_directories_names = [None] * self.L  # type: list
-        self.n_conditions_directories = [None] * self.L  # type: list
-        self.conditions_directories = [None] * self.L  # type: list
-
         self.order_accepted_values = 'ilcra'
         if order_outputs is None:
             self.order_outputs = 'il'
@@ -174,7 +201,6 @@ class Loader:
                 if not (self.order_outputs[o] in self.order_accepted_values):
                     raise ValueError('order_outputs')
 
-
         self.outputs = [None] * self.n_outputs  # type: list
 
         self.return_inputs_eb = 'i' in self.order_outputs
@@ -183,19 +209,14 @@ class Loader:
         self.return_relative_directories_eb = 'r' in self.order_outputs
         self.return_absolute_directories_eb = 'a' in self.order_outputs
 
-        directory_root_l = self.directory_root
+        self.n_conditions_directories = [None] * self.L  # type: list
         for l in range(self.L):
-            self.conditions_directories_names[l] = os.listdir(directory_root_l)
-
-            if conditions_directories[l] is None:
+            if self.conditions_directories[l] is None:
                 self.n_conditions_directories[l] = len(self.conditions_directories_names[l])
                 self.conditions_directories[l] = np.arange(self.n_conditions_directories[l])
             else:
-                self.conditions_directories[l] = conditions_directories[l]
                 self.n_conditions_directories[l] = len(self.conditions_directories[l])
 
-            directory_root_l = os.path.join(directory_root_l, self.conditions_directories_names[l][0])
-
         if self.time is not None:
             if self.time.range_time.stop is None:
                 self.time.range_time.stop = self.n_conditions_directories[self.time.level]
@@ -203,7 +224,7 @@ class Loader:
                 self.conditions_directories[self.time.level][self.time.range_time.to_slice()])
             self.n_conditions_directories[self.time.level] = len(self.conditions_directories[self.time.level])
 
-        self.K = self.n_classes = self.n_conditions_directories[self.level_classes]
+        self.K = self.n_classes = self.n_conditions_directories[self.levels_labels]
         self.V = self.n_variables = len(self.n_conditions_directories)
         self.n_samples = cc_maths.prod(self.n_conditions_directories)
         # self.n_samples = math.prod(self.n_conditions_directories)
@@ -244,7 +265,7 @@ class Loader:
             # self.combinations_directories[:, self.time.level] += self.time.shifts
             if self.return_labels_eb:
                 self.labels = torch.tensor(
-                    self.combinations_directories_no_shift[slice(0, self.n_samples, 1), self.level_classes],
+                    self.combinations_directories_no_shift[slice(0, self.n_samples, 1), self.levels_labels],
                     dtype=torch.int64, device=self.device)
             else:
                 self.labels = None
@@ -255,7 +276,7 @@ class Loader:
                 cc_combinations.conditions_to_combinations(self.conditions_directories))
             if self.return_labels_eb:
                 self.labels = torch.tensor(
-                    self.combinations_directories[slice(0, self.n_samples, 1), self.level_classes],
+                    self.combinations_directories[slice(0, self.n_samples, 1), self.levels_labels],
                     dtype=torch.int64, device=self.device)
             else:
                 self.labels = None
@@ -311,23 +332,7 @@ class Loader:
         Raises
         ------
         ValueError
-            somenthing
-
-        Examples
-        --------
-        example 1:
-
-        >>> a = 2
-        >>> b = 3
-        >>> a + b
-        5
-
-        example 2:
-
-        >>> a = 2
-        >>> b = 3
-        >>> a * b
-        6
+            something
 
         """
 
