@@ -9,7 +9,7 @@ from .. import format as cc_format
 from .. import check as cc_check
 
 
-def single_plot(
+def single_plot_single_figure(
         data, dict_axes=None, ax=None, ratio_fig=None, add_cbar=True, maximum_n_pixels_per_plot=500,
         annot=False, array_annot=None, fmt_annot='{:.2f}', colors_annot=["black", "white"],
         threshold_change_color_anno=None, tight_layout=True, **kwargs):
@@ -357,7 +357,7 @@ def single_plot(
         plt.tight_layout()
 
 
-def multi_plots_1_figure(
+def multi_plots_single_figure(
         data, dict_axes=None, id_figure=None, ratio_fig=None, sharex='none', sharey='none',
         array_annot=None, add_letters_to_titles=True,
         hspace=None, wspace=None, maximum_n_pixels_per_plot=500, tight_layout=True, **kwargs):
@@ -527,7 +527,7 @@ def multi_plots_1_figure(
 
             index[axes_subplots_sort] = subplots_combinations[s]
 
-            single_plot(
+            single_plot_single_figure(
                 data[tuple(index)], dict_axes=dict_axes_next, tight_layout=False,
                 ax=ax[tuple(subplots_combinations[tuple(indexes_subplots_combinations)])],
                 **dict(zip(keys, [value[tuple(index_kwargs)] for value in kwargs.values()])))
@@ -546,7 +546,7 @@ def multi_plots_1_figure(
 
             index[axes_subplots_sort] = subplots_combinations[s]
 
-            single_plot(
+            single_plot_single_figure(
                 data[tuple(index)], dict_axes=dict_axes_next, tight_layout=False,
                 ax=ax[tuple(subplots_combinations[tuple(indexes_subplots_combinations)])],
                 array_annot=array_annot[tuple(index)],
@@ -672,7 +672,7 @@ def multi_plots_multi_figures(
 
             index[dict_axes['figures']] = f
 
-            multi_plots_1_figure(
+            multi_plots_single_figure(
                 data[tuple(index)], dict_axes=dict_axes_next,
                 id_figure=id_figures[f], ratio_fig=ratio_fig, sharex=sharex[f], sharey=sharey[f],
                 array_annot=None,
@@ -688,11 +688,10 @@ def multi_plots_multi_figures(
 
             index[dict_axes['figures']] = f
 
-            multi_plots_1_figure(
+            multi_plots_single_figure(
                 data[tuple(index)], dict_axes=dict_axes_next,
                 id_figure=id_figures[f], ratio_fig=ratio_fig, sharex=sharex[f], sharey=sharey[f],
                 array_annot=array_annot[tuple(index)],
                 hspace=hspace[f], maximum_n_pixels_per_plot=maximum_n_pixels_per_plot[f],
                 add_letters_to_titles=add_letters_to_titles[f],
                 **dict(zip(keys, [value[tuple(index_kwargs)] for value in kwargs.values()])))
-
